#[repr(C)]pub struct VregGetVoltageStepResponse {
pub result: u32,
}Fields
result: u32Trait Implementations
Sourceimpl Clone for VregGetVoltageStepResponse
impl Clone for VregGetVoltageStepResponse
Sourcefn clone(&self) -> VregGetVoltageStepResponse
fn clone(&self) -> VregGetVoltageStepResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VregGetVoltageStepResponse
impl Debug for VregGetVoltageStepResponse
Sourceimpl<D: ResourceDialect> Decode<VregGetVoltageStepResponse, D> for VregGetVoltageStepResponse
impl<D: ResourceDialect> Decode<VregGetVoltageStepResponse, D> for VregGetVoltageStepResponse
Sourceimpl<D: ResourceDialect> Encode<VregGetVoltageStepResponse, D> for &VregGetVoltageStepResponse
impl<D: ResourceDialect> Encode<VregGetVoltageStepResponse, D> for &VregGetVoltageStepResponse
Sourceimpl<D: ResourceDialect, T0: Encode<u32, D>> Encode<VregGetVoltageStepResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<u32, D>> Encode<VregGetVoltageStepResponse, D> for (T0,)
Sourceimpl Hash for VregGetVoltageStepResponse
impl Hash for VregGetVoltageStepResponse
Sourceimpl Ord for VregGetVoltageStepResponse
impl Ord for VregGetVoltageStepResponse
Sourcefn cmp(&self, other: &VregGetVoltageStepResponse) -> Ordering
fn cmp(&self, other: &VregGetVoltageStepResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for VregGetVoltageStepResponse
impl PartialOrd for VregGetVoltageStepResponse
Sourceimpl TypeMarker for VregGetVoltageStepResponse
impl TypeMarker for VregGetVoltageStepResponse
Sourcetype Owned = VregGetVoltageStepResponse
type Owned = VregGetVoltageStepResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for VregGetVoltageStepResponse
impl ValueTypeMarker for VregGetVoltageStepResponse
Sourcetype Borrowed<'a> = &'a VregGetVoltageStepResponse
type Borrowed<'a> = &'a VregGetVoltageStepResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for VregGetVoltageStepResponse
impl Eq for VregGetVoltageStepResponse
impl Persistable for VregGetVoltageStepResponse
impl StructuralPartialEq for VregGetVoltageStepResponse