pub struct VregSetStateRequest {
pub step: Option<u32>,
pub enable: Option<bool>,
pub current_ua: Option<u32>,
pub mode: Option<RegulatorMode>,
/* private fields */
}Fields
step: Option<u32>enable: Option<bool>current_ua: Option<u32>mode: Option<RegulatorMode>Trait Implementations
Sourceimpl Clone for VregSetStateRequest
impl Clone for VregSetStateRequest
Sourcefn clone(&self) -> VregSetStateRequest
fn clone(&self) -> VregSetStateRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VregSetStateRequest
impl Debug for VregSetStateRequest
Sourceimpl<D: ResourceDialect> Decode<VregSetStateRequest, D> for VregSetStateRequest
impl<D: ResourceDialect> Decode<VregSetStateRequest, D> for VregSetStateRequest
Sourceimpl Default for VregSetStateRequest
impl Default for VregSetStateRequest
Sourcefn default() -> VregSetStateRequest
fn default() -> VregSetStateRequest
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<VregSetStateRequest, D> for &VregSetStateRequest
impl<D: ResourceDialect> Encode<VregSetStateRequest, D> for &VregSetStateRequest
Sourceimpl PartialEq for VregSetStateRequest
impl PartialEq for VregSetStateRequest
Sourceimpl TypeMarker for VregSetStateRequest
impl TypeMarker for VregSetStateRequest
Sourcetype Owned = VregSetStateRequest
type Owned = VregSetStateRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for VregSetStateRequest
impl ValueTypeMarker for VregSetStateRequest
Sourcetype Borrowed<'a> = &'a VregSetStateRequest
type Borrowed<'a> = &'a VregSetStateRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Persistable for VregSetStateRequest
impl StructuralPartialEq for VregSetStateRequest