#[repr(C)]pub struct VregSetVoltageStepRequest {
pub step: u32,
}Fields
step: u32Trait Implementations
Sourceimpl Clone for VregSetVoltageStepRequest
impl Clone for VregSetVoltageStepRequest
Sourcefn clone(&self) -> VregSetVoltageStepRequest
fn clone(&self) -> VregSetVoltageStepRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VregSetVoltageStepRequest
impl Debug for VregSetVoltageStepRequest
Sourceimpl<D: ResourceDialect> Decode<VregSetVoltageStepRequest, D> for VregSetVoltageStepRequest
impl<D: ResourceDialect> Decode<VregSetVoltageStepRequest, D> for VregSetVoltageStepRequest
Sourceimpl<D: ResourceDialect> Encode<VregSetVoltageStepRequest, D> for &VregSetVoltageStepRequest
impl<D: ResourceDialect> Encode<VregSetVoltageStepRequest, D> for &VregSetVoltageStepRequest
Sourceimpl<D: ResourceDialect, T0: Encode<u32, D>> Encode<VregSetVoltageStepRequest, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<u32, D>> Encode<VregSetVoltageStepRequest, D> for (T0,)
Sourceimpl Hash for VregSetVoltageStepRequest
impl Hash for VregSetVoltageStepRequest
Sourceimpl Ord for VregSetVoltageStepRequest
impl Ord for VregSetVoltageStepRequest
Sourcefn cmp(&self, other: &VregSetVoltageStepRequest) -> Ordering
fn cmp(&self, other: &VregSetVoltageStepRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for VregSetVoltageStepRequest
impl PartialOrd for VregSetVoltageStepRequest
Sourceimpl TypeMarker for VregSetVoltageStepRequest
impl TypeMarker for VregSetVoltageStepRequest
Sourcetype Owned = VregSetVoltageStepRequest
type Owned = VregSetVoltageStepRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for VregSetVoltageStepRequest
impl ValueTypeMarker for VregSetVoltageStepRequest
Sourcetype Borrowed<'a> = &'a VregSetVoltageStepRequest
type Borrowed<'a> = &'a VregSetVoltageStepRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for VregSetVoltageStepRequest
impl Eq for VregSetVoltageStepRequest
impl Persistable for VregSetVoltageStepRequest
impl StructuralPartialEq for VregSetVoltageStepRequest